@@ -1,6 +1,6 @@
 from ..core.project_manager import *
 from uquake.nlloc.nlloc import *
-from uquake.core.event import (Catalog, Event, CreationInfo, Origin)
+from uquake.core.event import (Catalog, Event, CreationInfo, Origin, Arrival)
 from uquake.core import UTCDateTime
 import numpy as np
 from pydantic import BaseModel
@@ -150,7 +150,8 @@ class NLLOCResult:
                         creation_info=self.creation_info,
                         arrivals=self.arrivals,
                         origin_uncertainty=self.uncertainty_ellipsoid,
-                        rays=self.rays)
+                        rays=self.rays,
+                        scatters=self.scatter_cloud)
         origin.rays = self.rays
         return origin
 
